@@ -5,7 +5,7 @@ use Module::Install::Base;
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.87';
+	$VERSION = '0.88';
 	@ISA     = qw{Module::Install::Base};
 }
 
@@ -50,6 +50,10 @@ sub auto_include_deps {
 
 =pod
 
+=head1 NAME
+
+Module::Install::Admin::Include
+
 =head2 auto_include_dependent_dists
 
 Grabs everything in this module's build_requires and attempts to
